﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
  <xsl:output method="html" encoding="utf-8" doctype-system="about:legacy-compat"/>
  
  <xsl:variable name="content" select="'content'"/>
  <xsl:variable name="ext" select="''"/>
  <xsl:variable name="resources" select="''"/>

  <!-- HTML head definition. -->
  <xsl:template name="head">
    <head>
      <meta charset="utf-8"/>
      <meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
    </head>
  </xsl:template>

  <!-- Object localization in documentation. -->
  <xsl:template match="Breadcrumbs">
    <div id="breadcrumb">
      <xsl:apply-templates select="Breadcrumb"/>
    </div>

    <xsl:if test="/DataDocumenter/LicenseTag">
      <div class="trial trial-content"> Trial </div>
    </xsl:if>
  </xsl:template>
  
  <!-- Object localization in documentation element. -->
  <xsl:template name="breadcrumb" match="Breadcrumb">
    <xsl:variable name="icon">
      <xsl:choose>
        <xsl:when test="@type = 'Documentation'"> icon-database </xsl:when>
        <xsl:when test="@type = 'Module'"> icon-module </xsl:when>
        <xsl:when test="@type = 'Function'"> icon-function </xsl:when>
        <xsl:when test="@type = 'Procedure'"> icon-procedure </xsl:when>
        <xsl:when test="@type = 'Table'"> icon-table </xsl:when>
        <xsl:when test="@type = 'View'"> icon-view </xsl:when>
        <xsl:when test="@type = 'Folder'"> icon-folder </xsl:when>
      </xsl:choose>
    </xsl:variable>

    <a href="#{@src}{$ext}" class="ajax" data-target="#right">
      <i class="{$icon}"></i>
      <xsl:value-of select="."/>
    </a>

    <xsl:if test="position() != last()"> › </xsl:if>
  </xsl:template>

  <!-- Basic information about object. -->
  <xsl:template name="objectInformation">
    <xsl:param name="objectType" />

    <h1>
      <span>
        <xsl:value-of select="$objectType"/>:
      </span>
      <xsl:value-of select="ObjectName"/>
      <xsl:if test="string-length(Title)>0"> (<xsl:value-of select="Title"/>)</xsl:if>
    </h1>

    <table class="table table-vertical">
      <tbody>
        <xsl:call-template name="row">
          <xsl:with-param name="name" select="'Schema'"/>
          <xsl:with-param name="value" select="Schema"/>
        </xsl:call-template>

        <xsl:call-template name="row">
          <xsl:with-param name="name" select="'Name'"/>
          <xsl:with-param name="value" select="Name"/>
        </xsl:call-template>

        <xsl:if test="string-length(Title)>0">
          <xsl:call-template name="row">
            <xsl:with-param name="name" select="'Title'"/>
            <xsl:with-param name="value" select="Title"/>
          </xsl:call-template>
        </xsl:if>

        <xsl:choose>
          <xsl:when test="count(Modules/Module)=1">
            <xsl:variable name="src">modules/<xsl:value-of select="Modules/Module/ObjectId"/>/module</xsl:variable>
            <xsl:call-template name="row">
              <xsl:with-param name="name" select="'Module'"/>
              <xsl:with-param name="src" select="$src"/>
              <xsl:with-param name="value" select="Modules/Module/Title"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="count(Modules/Module)>1">
             <tr>
              <td style="width: 15%;">Modules</td>
              <td>
                <xsl:for-each select="Modules/Module">
                  <xsl:variable name="src">modules/<xsl:value-of select="ObjectId"/>/module</xsl:variable>
                  <a href="#{$src}{$ext}" class="ajax" data-target="#right">
                    <xsl:value-of select="Title"/>
                  </a>
                  
                  <xsl:if test="position() != last()">, </xsl:if>
                </xsl:for-each>
              </td>
            </tr>
          </xsl:when>
        </xsl:choose>
      </tbody>
    </table>

    <xsl:if test="Description and Description != ''">
      <div class="element description">
        <div class="html">
          <xsl:value-of select="Description" disable-output-escaping="yes"/>
        </div>
      </div>
    </xsl:if>
  </xsl:template>

  <!-- Metadata. -->
  <xsl:template name="metadata">
    <div>
      <div class="font-gray">
        Exported: <xsl:value-of select="Exported"/><xsl:if test="LastImported and LastImported != ''">, Last imported: <xsl:value-of select="LastImported"/></xsl:if>
      </div>

      <xsl:call-template name="edition"/>
    </div>
  </xsl:template>

  <!-- Edition. -->
  <xsl:template name="edition">
    <xsl:if test="/DataDocumenter/Edition">
      <div class="font-gray" style="margin-top: 15px">
        <xsl:value-of select="/DataDocumenter/Edition"/>
      </div>
    </xsl:if>
  </xsl:template>
  
  <!-- Row in information table. -->
  <xsl:template name="row">
    <xsl:param name="name" />
    <xsl:param name="src" />
    <xsl:param name="value" />

    <xsl:if test="$value and $value != ''">
      <tr>
        <td style="width: 15%;">
          <xsl:value-of select="$name"/>
        </td>
        <xsl:choose>
          <xsl:when test="$src">
            <td>
              <a href="#{$src}{$ext}" class="ajax" data-target="#right">
                <xsl:value-of select="$value"/>
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td>
              <xsl:value-of select="$value"/>
            </td>
          </xsl:otherwise>
        </xsl:choose>
      </tr>
    </xsl:if>
  </xsl:template>

  <!-- Inserts new lines for HTML (<br/>). -->
  <xsl:template name="insertHtmlNewLines">
    <xsl:param name="value" />

    <xsl:choose>
      <!-- Return value if there is not new lines. -->
      <xsl:when test="not(contains($value, '&#xA;'))">
        <xsl:value-of select="$value"/>
      </xsl:when>
      <xsl:otherwise>
        <!-- Return value before new line. -->
        <xsl:value-of select="substring-before($value, '&#xA;')"/>
        
        <br/>

        <!-- Check new lines in rest of value. -->
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="substring-after($value, '&#xA;')"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>