<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
    <xsl:include href="_common.xsl"/>
    
    <xsl:output method="html" encoding="utf-8" doctype-system="about:legacy-compat"/>

    <!-- Default template -->
    <xsl:template match="*"></xsl:template>

    <!-- Redirection -->
    <xsl:template match="/DataDocumenter">
      <html>
            <head>
                <meta charset="utf-8"/>
          <meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
            </head>
            <body>
                <xsl:call-template name="breadcrumbs"/>
                <xsl:call-template name="documentation"/>
                <xsl:call-template name="modules"/>
                <xsl:call-template name="objects"/>
            </body>
        </html>
    </xsl:template>

    <!-- Breadcrumb -->
    <xsl:template name="breadcrumbs">
      <div id="breadcrumb">
        <xsl:apply-templates select="Breadcrumbs/Breadcrumb"/>
      </div>

      <xsl:if test="/DataDocumenter/LicenseTag">
        <div class="trial trial-content"> Trial </div>
      </xsl:if>
    </xsl:template>

    <xsl:template match="Breadcrumbs/Breadcrumb">
      <xsl:variable name="icon">
      <xsl:choose>
        <xsl:when test="@type = 'Documentation'"> icon-database </xsl:when>
        <xsl:when test="@type = 'Module'"> icon-module </xsl:when>
        <xsl:when test="@type = 'Function'"> icon-function </xsl:when>
        <xsl:when test="@type = 'Procedure'"> icon-procedure </xsl:when>
        <xsl:when test="@type = 'Table'"> icon-table </xsl:when>
        <xsl:when test="@type = 'View'"> icon-view </xsl:when>
                <xsl:when test="@type = 'Folder'"> icon-folder </xsl:when>
      </xsl:choose>
    </xsl:variable>

      <a href="#{@src}{$ext}" class="ajax" data-target="#right"><i class="{$icon}"></i><xsl:value-of select="."/></a>
        <xsl:if test="position() != last()"> › </xsl:if>
    </xsl:template>

    <!-- Basic data -->
    <xsl:template name="documentation">
      <h1><xsl:value-of select="Documentation/Name"/> – Data Dictionary</h1>

      <table class="table table-vertical">
        <tbody>
          <xsl:apply-templates select="Documentation/TableData/Row"/>
        </tbody>
      </table>

      <xsl:if test="Documentation/Description != ''">
        <div class="element description">
          <div class="html">
            <xsl:value-of select="Documentation/Description" disable-output-escaping="yes"/>
          </div>
        </div>
      </xsl:if>
    </xsl:template>

    <xsl:template match="Documentation/TableData/Row">
      <tr>
          <td style="width: 15%;"><xsl:value-of select="@name"/></td>
          <td><xsl:value-of select="."/></td>
      </tr>
    </xsl:template>

    <!-- Modules -->
    <xsl:template name="modules">
      <xsl:choose>
        <xsl:when test="Modules/*">
          <div class="element">
              <h2> Modules </h2>
              <ol><xsl:apply-templates select="Modules/Module"/></ol>
          </div>
        </xsl:when>
    </xsl:choose>
    </xsl:template>

    <xsl:template match="Modules/Module">
      <li><a href="#{@src}{$ext}" class="ajax" data-target="#right"><xsl:value-of select="."/></a></li>
    </xsl:template>

    <!-- Object types -->
    <xsl:template name="objects">
      <xsl:choose>
        <xsl:when test="DatabaseObjects/*">
          <div class="element">
              <h2> Database objects </h2>
              <ol><xsl:apply-templates select="DatabaseObjects/Object"/></ol>
          </div>
        </xsl:when>
    </xsl:choose>
    </xsl:template>

    <xsl:template match="DatabaseObjects/Object">
      <xsl:choose>
        <xsl:when test="@count > 0">
          <li>
            <a href="#{@src}{$ext}" class="ajax" data-target="#right">
              <xsl:value-of select="."/>
            </a> (<xsl:value-of select="@count"/>)
          </li>
        </xsl:when>
      </xsl:choose>
    </xsl:template>

</xsl:stylesheet>