<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
  <xsl:include href="_common.xsl"/>
  <xsl:include href="_dependencies.xsl"/>

  <!-- Type of object for header -->
  <xsl:variable name="objectType" select="'Object'"/>

  <!-- Root -->
  <xsl:template match="/DataDocumenter">
    <xsl:variable name="pathPart" select="Breadcrumbs/Breadcrumb[last()]/@src"/>
      <div data-page="{$pathPart}{$ext}">
        <xsl:apply-templates select="Breadcrumbs"/>
        <xsl:apply-templates select="Procedure | Function"/>

        <xsl:call-template name="applyDependenciesEvents"/>
      </div>
  </xsl:template>

  <!-- Object information for procedure or function -->
  <xsl:template match="Procedure | Function">
    <xsl:call-template name="objectInformation">
      <xsl:with-param name="objectType" select="$objectType"/>
    </xsl:call-template>

    <xsl:apply-templates select="InputOutputs"/>
    <xsl:apply-templates select="Dependencies"/>

    <xsl:call-template name="metadata"/>
  </xsl:template>

  <!-- Columns -->
  <xsl:template match="InputOutputs">
    <xsl:choose>
      <xsl:when test="./*">
        <div class="scroll-x">
          <table class="table sortable">
            <caption>Input/Output</caption>
            <thead>
              <tr>
                <th style="width: 40px !important"></th>
                <th style="width: 100px">Mode</th>
                <th>Name</th>
                <th style="width: 170px">Data type</th>
                <th class="only-desktop">Description</th>
              </tr>
            </thead>
            <tbody>
              <xsl:apply-templates select="InputOutput"/>
            </tbody>
          </table>
        </div>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Column -->
  <xsl:template match="InputOutput">
    <tr>
      <td>
        <xsl:value-of select="OrdinalPosition"/>
      </td>
      <td>
        <xsl:value-of select="Mode"/>
      </td>
      <td>
        <xsl:value-of select="Name"/>
      </td>
      <td>
        <xsl:value-of select="DataType"/>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>
    </tr>

    <xsl:if test="string-length(Description)>0">
      <tr class="only-mobile">
        <td colspan="4">
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <!-- Dependencies -->
  <xsl:template match="Dependencies">
    <xsl:apply-templates select="Uses">
      <xsl:with-param name="objectType" select="$objectType"/>
      <xsl:with-param name="content" select="$content"/>
      <xsl:with-param name="ext" select="$ext"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="UsedBy">
      <xsl:with-param name="objectType" select="$objectType"/>
      <xsl:with-param name="content" select="$content"/>
      <xsl:with-param name="ext" select="$ext"/>
    </xsl:apply-templates>
  </xsl:template>
</xsl:stylesheet>